#include <libxml/parser.h>
#include <libxml/tree.h>
#include <stdlib.h>
#include <string.h>
#include "gigs_processor.h"

// Updated function to parse the .gig file and extract the relevant data
GigData* parse_gig_file(const char *filename) {
    xmlDoc *doc = xmlReadFile(filename, NULL, 0);
    if (doc == NULL) {
        printf("Error: unable to parse file \"%s\"\n", filename);
        return NULL;
    }

    xmlNode *root_element = xmlDocGetRootElement(doc);
    GigData *gig = (GigData*)malloc(sizeof(GigData));
    memset(gig, 0, sizeof(GigData));  // Initialize all struct members to NULL

    // Traverse the XML structure
    for (xmlNode *cur_node = root_element; cur_node; cur_node = cur_node->next) {
        if (cur_node->type == XML_ELEMENT_NODE) {
            // Parse the musician data
            if (!xmlStrcmp(cur_node->name, (const xmlChar *)"musician")) {
                gig->name = (char*)xmlGetProp(cur_node, (const xmlChar *)"name");
                gig->src = (char*)xmlGetProp(cur_node, (const xmlChar *)"src");
                
                // Find the <video> element inside the musician node
                for (xmlNode *musician_node = cur_node->children; musician_node; musician_node = musician_node->next) {
                    if (!xmlStrcmp(musician_node->name, (const xmlChar *)"video")) {
                        gig->video_src = (char*)xmlGetProp(musician_node, (const xmlChar *)"src");
                    }
                }
            }

            // Parse the schedule data
            if (!xmlStrcmp(cur_node->name, (const xmlChar *)"schedule")) {
                // Traverse the children of <schedule>
                for (xmlNode *schedule_node = cur_node->children; schedule_node; schedule_node = schedule_node->next) {
                    if (!xmlStrcmp(schedule_node->name, (const xmlChar *)"ical")) {
                        gig->schedule_url = (char*)xmlGetProp(schedule_node, (const xmlChar *)"src");
                    } else if (!xmlStrcmp(schedule_node->name, (const xmlChar *)"location")) {
                        gig->location_url = (char*)xmlGetProp(schedule_node, (const xmlChar *)"src");
                        gig->location_text = (char*)xmlNodeGetContent(schedule_node);  // Get the location text (e.g., Oslo, Norway)
                    }
                }
            }
        }
    }

    xmlFreeDoc(doc);  // Clean up XML document
    return gig;
}

// Free the dynamically allocated memory for the GigData structure
void free_gig_data(GigData *gig) {
    if (gig) {
        free(gig->name);
        free(gig->src);
        free(gig->video_src);
        free(gig->schedule_url);
        free(gig->location_url);
        free(gig->location_text);
        free(gig);
    }
}
