#ifndef GIGS_PROCESSOR_H
#define GIGS_PROCESSOR_H

#include <libxml/parser.h>
#include <libxml/tree.h>

// Updated struct to hold parsed .gig file data
typedef struct {
    char *name;           // Musician's name
    char *src;            // Musician's URL
    char *video_src;      // Video stream URL
    char *schedule_url;   // Schedule (iCalendar link) URL
    char *location_url;   // Location URL (in the schedule)
    char *location_text;  // Location text (e.g., "Oslo, Norway")
} GigData;

/**
 * Function to parse the .gig file and extract the relevant data.
 * 
 * @param filename The path to the .gig XML file to parse.
 * @return A pointer to the GigData structure containing parsed data. Returns NULL on error.
 */
GigData* parse_gig_file(const char *filename);

/**
 * Function to free the dynamically allocated memory in a GigData struct.
 * 
 * @param gig A pointer to the GigData structure to free.
 */
void free_gig_data(GigData *gig);

#endif // GIGS_PROCESSOR_H
